==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/PortStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PortStatusBuilder extends io.fabric8.kubernetes.api.model.PortStatusFluentImpl<io.fabric8.kubernetes.api.model.PortStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PortStatus,io.fabric8.kubernetes.api.model.PortStatusBuilder>{
  public PortStatusBuilder() {
    this(false);
  }
  public PortStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new PortStatus(), validationEnabled);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PortStatus(), validationEnabled);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PortStatus instance) {
    this(fluent, instance, false);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PortStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withError(instance.getError()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    this.validationEnabled = validationEnabled; 
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatus instance) {
    this(instance,false);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withError(instance.getError()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PortStatus build() {
    PortStatus buildable = new PortStatus(fluent.getError(),fluent.getPort(),fluent.getProtocol());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortStatusBuilder that = (PortStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PortStatusBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PortStatusBuilder extends io.fabric8.kubernetes.api.model.PortStatusFluentImpl<io.fabric8.kubernetes.api.model.PortStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PortStatus,io.fabric8.kubernetes.api.model.PortStatusBuilder>{
  public PortStatusBuilder() {
    this(false);
  }
  public PortStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new PortStatus(), validationEnabled);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PortStatus(), validationEnabled);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PortStatus instance) {
    this(fluent, instance, false);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.PortStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withError(instance.getError()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatus instance) {
    this(instance,false);
  }
  public PortStatusBuilder(io.fabric8.kubernetes.api.model.PortStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withError(instance.getError()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PortStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PortStatus build() {
    PortStatus buildable = new PortStatus(fluent.getError(),fluent.getPort(),fluent.getProtocol());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortStatusBuilder that = (PortStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
